Index: cc/trees/layer_tree_host_client.h |
diff --git a/cc/trees/layer_tree_host_client.h b/cc/trees/layer_tree_host_client.h |
index 73ec892268983fff97569251edaa6ef0b0b4d628..95480eff0ae1b576779a4b396d3115e6bb4c15d4 100644 |
--- a/cc/trees/layer_tree_host_client.h |
+++ b/cc/trees/layer_tree_host_client.h |
@@ -30,9 +30,11 @@ class LayerTreeHostClient { |
virtual void ApplyViewportDeltas(const gfx::Vector2d& scroll_delta, |
float page_scale, |
float top_controls_delta) = 0; |
- // Creates an OutputSurface. If fallback is true, it should attempt to |
- // create an OutputSurface that is guaranteed to initialize correctly. |
- virtual scoped_ptr<OutputSurface> CreateOutputSurface(bool fallback) = 0; |
+ // Request an OutputSurface from the client. When the client has one it should |
+ // call LayerTreeHost::SetOutputSurface. If fallback is true, it should |
+ // attempt to create an OutputSurface that is guaranteed to initialize |
+ // correctly. |
+ virtual void RequestNewOutputSurface(bool fallback) = 0; |
virtual void DidInitializeOutputSurface() = 0; |
virtual void WillCommit() = 0; |
virtual void DidCommit() = 0; |